==> php81-nextcloud-28.0.6.tgz: share/nextcloud/apps/photos/l10n/bg.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Публична връзка",
    "Photos" : "Снимки",
    "Your memories under your control" : "Вашите спомени под ваш контрол",
    "All media" : "Всички медии",
    "Videos" : "Видеа",
    "Albums" : "Албуми",
    "Collaborative albums" : "Съвместни албуми",
    "People" : "Хора",
    "Folders" : "Папки",
    "Favorites" : "Любими",
    "On this day" : "На този ден",
    "Shared with you" : "Споделени с вас",
    "Tags" : "Етикети",
    "Places" : "Места",
    "Map" : "Карта",
    "Photos settings" : "Настройки на снимки",
    "Mark selection as favorite" : "Маркиране на селекцията като любима",
    "Add selection to favorites" : "Добавяне на селекция към любими",
    "Remove selection from favorites" : "Премахване на селекция от любими",
    "Name of the album" : "Име на албума",
    "Location of the album" : "Местоположение на албума",
    "Back" : "Назад",
    "Add collaborators" : "Добавяне на сътрудници",
    "Save" : "Запиши",
    "Create album" : "Създаване на албум",
    "Add to Album" : "Добавяне към Албум",
    "Add selection to album {albumName}" : "Добавяне на селекция към албум {ablumName}",
    "Shared by" : "Споделено от",
    "Create a new album." : "Създаване на нов албум.",
    "Create new album" : "Създаване на нов албум",
    "New album" : "Нов албум",
    "_%n item_::_%n photos and videos_" : ["%n снимки и видеоклипове","%n снимки и видеоклипове"],
    "Add people or groups who can edit your album" : "Добавяне на хора или групи, които могат да редактират вашият албум",
    "Search people or groups" : "Търсене на хора или групи",
    "No recommendations. Start typing." : "Няма препоръки. Започнете да пишете.",
    "Remove {collaboratorLabel} from the collaborators list" : "Премахване на {collaboratorLabel} от списъка със сътрудници",
    "Copy the public link" : "Копиране на публичната връзка",
    "Public link copied!" : "Копирана е публична връзка!",
    "Copy public link" : "Копирай публичната връзка",
    "Delete the public link" : "Изтриване на публичната връзка",
    "Share via public link" : "Споделяне чрез публична връзка",
    "Failed to fetch collaborators list." : "Неуспешно извличане на списък със сътрудници.",
    "Failed to update album." : "Неуспешно обновяване на албум.",
    "This collection does not exist" : "Тази колекция не съществува",
    "An error occurred" : "Възникна грешка",
    "Favorite" : "Любими",
    "Select image {imageName}" : "Избор на изображение {imageName}",
    "Open the full size \"{name}\" image" : "Отваряне на изображението\"{name}“  в пълен размер ",
    "Go back" : "Назад",
    "Back to {folder}" : "Назад към {folder}",
    "Share this folder" : "Споделяне на тази папка",
    "Add to {destination}" : "Добавяне към  {destination}",
    "There are no photos or videos yet!" : "Все още няма снимки или видеоклипове!",
    "_{years} year ago_::_{years} years ago_" : ["Преди {years} години","Преди {years} години"],
    "Enable squared photos view" : "Активирайте изгледа на снимки в квадратче",
    "Add folder" : "Добави папка",
    "Home" : "Начало",
    "View" : "Изглед",
    "_%n photo_::_%n photos_" : ["%n снимки","%n снимки"],
    "Unselect all" : "Отмяна на избора на всички",
    "Manage collaborators for this album" : "Управление на сътрудници за този албум",
    "Open actions menu" : "Отворяне на менюто с действия",
    "Edit album details" : "Редактиране на подробности за албума",
    "Download all files in album" : "Изтегляне на всички файлове в албума",
    "Delete album" : "Изтриване на албум",
    "Download selected files" : "Изтегляне на избраните файлове",
    "Remove selection from album" : "Премахване на селекция от албума",
    "This album does not have any photos or videos yet!" : "Този албум все още няма снимки или видеоклипове!",
    "Add photos to this album" : "Добавяне на снимки към този албум",
    "Manage collaborators" : "Управление на сътрудници",
    "Save collaborators for this album." : "Запис на сътрудници за този албум.",
    "Cover photo for album {albumName}" : "Снимка на корицата на албум {albumName}",
    "There is no album yet!" : "Все още няма албум!",
    "This person could not be found" : "Това лице не може да бъде намерено",
    "Rename person" : "Преименуване на лице",
    "Merge with different person" : "Обединяване с различно лице",
    "Download selected photos" : "Изтегляне на избрани снимки",
    "Remove from favorites" : "Премахване от любими",
    "Remove person" : "Премахване на лице",
    "Name of this person" : "Име лицето",
    "Save." : "Запиши.",
    "Merge person" : "Обединяване на лице",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Преместване на снимки към друго лице","Преместване на снимки към друго лице"],
    "_Remove photo from person_::_Remove photos from person_" : ["Премахване на снимки от лице","Премахване на снимки от лице"],
    "This might take some time depending on the size of your photo library." : "Това може да отнеме известно време в зависимост от размера на вашата библиотека със снимки.",
    "Recognized people will show up here" : "Разпознатите хора ще се показват тук",
    "This folder does not exist" : "Тази папка не съществува",
    "Loading folders …" : "Зареждане на папките …",
    "No photos in here" : "Тук няма снимки",
    "This place does not have any photos or videos yet!" : "Това място все още няма снимки или видеоклипове!",
    "Add photos to this place" : "Добавяне на снимки към това място",
    "Cover photo for place {placeName}" : "Снимка на корицата за място {placeName}",
    "There is no place yet!" : "Все още няма място!",
    "Cover photo for shared album {albumName}." : "Снимка на корицата на споделен албум {albumName}",
    "Back to tags overview" : "Обратно към преглед на етикети",
    "No photos with this tag yet" : "Все още няма снимки с този етикет",
    "No tags yet" : "Все още няма етикети",
    "Photos with tags will show up here" : " Снимки с етикети ще се покажат тук",
    "Popular tags" : "Популярни етикети",
    "Add" : "Добавяне",
    "Add to album" : "Добавяне към албум",
    "Delete selection" : "Изтриите селекцията",
    "No photos or videos in here" : "Тук няма снимки или видеоклипове",
    "_%n photos_::_%n photos_" : ["%n снимки ","%n снимки"],
    "Failed to fetch collection." : "Неуспешно извличане на колекция.",
    "Failed to fetch collections list." : "Неуспешно извличане на списък с колекции.",
    "Failed to fetch faces list." : "Неуспешно извличане на списък с лица.",
    "All your media" : "Всички ваши медии",
    "Album {title}" : "Албум {title}",
    "Shared Albums" : "Споделени албуми",
    "Shared album {title}" : "Споделен албум {title}",
    "Public album {title}" : "Публичен албум {title}",
    "Tagged photos" : "Маркирани снимки",
    "Tagged photo {title}" : "Маркирана снимка {title}",
    "{title}'s face" : "Лицето на {title}",
    "{startDate} to {endDate}" : "{startDate} до {endDate}",
    "Details" : "Подробности",
    "Failed to rename {oldName} to {faceName}." : "Неуспешно преименуване от {oldName} на {faceName}.",
    "Failed to delete {faceName}." : "Неуспешно изтриване на {faceName}.",
    "Failed to delete {fileId}." : "Неуспешно изтриване на {fileId}.",
    "Failed to delete {fileName}." : "Неуспешно изтриване на {fileName}.",
    "Failed to set favorite state for {fileId}." : "Неуспешно задаване на предпочитано/любимо/ състояние за {fileId}.",
    "Failed to set favorite state for {fileName}." : "Неуспешно задаване на предпочитано/любимо/ състояние за {fileName}.",
    "Go back to the previous view." : "Връщане към предишния изглед.",
    "Go to the add collaborators view." : "Отиване до изглед за добавяне на сътрудници.",
    "Create the album." : "Създаване на албума.",
    "Back to the new album form." : "Обратно към формата на новия албум.",
    "_Share with %n user_::_Share with %n users_" : ["Споделяне с %n потребители","Споделяне с %n потребители"],
    "Search for collaborators" : "Търсене на сътрудници",
    "Add {collaboratorLabel} to the collaborators list" : "Добавяне на {collaboratorLabel} към списъка със сътрудници",
    "No collaborators available" : "Няма налични сътрудници",
    "Failed to fetch album." : "Неуспешно извличане на албум.",
    "The file is in the favorites" : "Файлът е в любими",
    "Open the \"{name}\" sub-directory" : "Отваряне на \"{name}“  поддиректория ",
    "Default Photos upload and Albums location" : "Качване на снимки и местоположение на албуми по подразбиране",
    "Select the default location for your media" : "Избор на местоположение по подразбиране за вашата медия",
    "Invalid location selected" : "Избрано е невалидно местоположение",
    "Photos directory" : "Директория със снимки",
    "Add photos to the album" : "Добавяне на снимки към албума",
    "Failed to fetch albums list." : "Неуспешно извличане на списък с албуми.",
    "Shared albums" : "Споделени албуми",
    "Create a new album" : "Създаване на нов албум",
    "Add selection to an album" : "Добавяне на селекция към албум",
    "Failed to create {albumName}." : "Неуспешно създаване на {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Неуспешно преименуване от {currentAlbumName} на {newAlbumName}."
},
"nplurals=2; plural=(n != 1);");

==> php81-nextcloud-30.0.15.tgz: share/nextcloud/apps/photos/l10n/bg.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Публична връзка",
    "Photos" : "Снимки",
    "On This Day" : "На този ден",
    "Your memories under your control" : "Вашите спомени под ваш контрол",
    "All media" : "Всички медии",
    "Videos" : "Видеа",
    "Albums" : "Албуми",
    "Collaborative albums" : "Съвместни албуми",
    "People" : "Хора",
    "Folders" : "Папки",
    "Favorites" : "Любими",
    "On this day" : "На този ден",
    "Shared with you" : "Споделени с вас",
    "Tags" : "Етикети",
    "Places" : "Места",
    "Map" : "Карта",
    "Photos settings" : "Настройки на снимки",
    "Mark selection as favorite" : "Маркиране на селекцията като любима",
    "Add selection to favorites" : "Добавяне на селекция към любими",
    "Remove selection from favorites" : "Премахване на селекция от любими",
    "Name of the album" : "Име на албума",
    "Location of the album" : "Местоположение на албума",
    "Back" : "Назад",
    "Add collaborators" : "Добавяне на сътрудници",
    "Save" : "Запиши",
    "Create album" : "Създаване на албум",
    "Add to Album" : "Добави към Албум",
    "Add selection to album {albumName}" : "Добавяне на селекция към албум {ablumName}",
    "Shared by" : "Споделено от",
    "Create a new album." : "Създаване на нов албум.",
    "Create new album" : "Създаване на нов албум",
    "New album" : "Нов албум",
    "_%n item_::_%n photos and videos_" : ["%n снимки и видеоклипове","%n снимки и видеоклипове"],
    "Failed to fetch collaborators list." : "Неуспешно извличане на списък със сътрудници.",
    "Failed to update album." : "Неуспешно обновяване на албум.",
    "Add people or groups who can edit your album" : "Добавяне на хора или групи, които могат да редактират вашият албум",
    "Search people or groups" : "Търсене на хора или групи",
    "No recommendations. Start typing." : "Няма препоръки. Започнете да пишете.",
    "Copy the public link" : "Копиране на публичната връзка",
    "Public link copied!" : "Копирана е публична връзка!",
    "Copy public link" : "Копирай публичната връзка",
    "Delete the public link" : "Изтриване на публичната връзка",
    "Share via public link" : "Споделяне чрез публична връзка",
    "This collection does not exist" : "Тази колекция не съществува",
    "An error occurred" : "Възникна грешка",
    "No picture for this day" : "Няма снимка за днешния ден",
    "Picture taken on this day will show up here." : "Снимки, заснети на този ден, ще се показват тук.",
    "_%n photos_::_%n photos_" : ["%n снимки ","%n снимки"],
    "Favorite" : "Любими",
    "Open the full size \"{name}\" image" : "Отваряне на изображението\"{name}“  в пълен размер ",
    "Select image {imageName}" : "Избор на изображение {imageName}",
    "Go back" : "Назад",
    "Add to {destination}" : "Добавяне към  {destination}",
    "There are no photos or videos yet!" : "Все още няма снимки или видеоклипове!",
    "_{years} year ago_::_{years} years ago_" : ["Преди {years} години","Преди {years} години"],
    "Enable squared photos view" : "Активирайте изгледа на снимки в квадратче",
    "Add folder" : "Добави папка",
    "Home" : "Начало",
    "View" : "Изглед",
    "_%n photo_::_%n photos_" : ["%n снимки","%n снимки"],
    "Unselect all" : "Отмяна на избора на всички",
    "Add photos to this album" : "Добавяне на снимки към този албум",
    "Manage collaborators for this album" : "Управление на сътрудници за този албум",
    "Open actions menu" : "Отворяне на менюто с действия",
    "Edit album details" : "Редактиране на подробности за албума",
    "Download all files in album" : "Изтегляне на всички файлове в албума",
    "Delete album" : "Изтриване на албум",
    "Download selected files" : "Изтегляне на избраните файлове",
    "Remove selection from album" : "Премахване на селекция от албума",
    "This album does not have any photos or videos yet!" : "Този албум все още няма снимки или видеоклипове!",
    "Manage collaborators" : "Управление на сътрудници",
    "Save collaborators for this album." : "Запис на сътрудници за този албум.",
    "Cover photo for album {albumName}" : "Снимка на корицата на албум {albumName}",
    "There is no album yet!" : "Все още няма албум!",
    "This person could not be found" : "Това лице не може да бъде намерено",
    "Rename person" : "Преименуване на лице",
    "Merge with different person" : "Обединяване с различно лице",
    "Download selected photos" : "Изтегляне на избрани снимки",
    "Remove from favorites" : "Премахване от любими",
    "Remove person" : "Премахване на лице",
    "Name of this person" : "Име лицето",
    "Save." : "Запиши.",
    "Merge person" : "Обединяване на лице",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Преместване на снимки към друго лице","Преместване на снимки към друго лице"],
    "_Remove photo from person_::_Remove photos from person_" : ["Премахване на снимки от лице","Премахване на снимки от лице"],
    "This might take some time depending on the size of your photo library." : "Това може да отнеме известно време в зависимост от размера на вашата библиотека със снимки.",
    "Recognized people will show up here" : "Разпознатите хора ще се показват тук",
    "This folder does not exist" : "Тази папка не съществува",
    "Loading folders…" : "Зареждане на папките…",
    "No photos in here" : "Тук няма снимки",
    "This place does not have any photos or videos yet!" : "Това място все още няма снимки или видеоклипове!",
    "Add photos to this place" : "Добавяне на снимки към това място",
    "Cover photo for place {placeName}" : "Снимка на корицата за място {placeName}",
    "There is no place yet!" : "Все още няма място!",
    "Back to tags overview" : "Обратно към преглед на етикети",
    "No photos with this tag yet" : "Все още няма снимки с този етикет",
    "No tags yet" : "Все още няма етикети",
    "Photos with tags will show up here" : " Снимки с етикети ще се покажат тук",
    "Popular tags" : "Популярни етикети",
    "Add to album" : "Добави към албум",
    "Delete selection" : "Изтриите селекцията",
    "No photos or videos in here" : "Тук няма снимки или видеоклипове",
    "Failed to fetch collection." : "Неуспешно извличане на колекция.",
    "Failed to fetch collections list." : "Неуспешно извличане на списък с колекции.",
    "Failed to fetch faces list." : "Неуспешно извличане на списък с лица.",
    "All your media" : "Всички ваши медии",
    "Album {title}" : "Албум {title}",
    "Shared Albums" : "Споделени албуми",
    "Shared album {title}" : "Споделен албум {title}",
    "Public album {title}" : "Публичен албум {title}",
    "Tagged photos" : "Маркирани снимки",
    "Tagged photo {title}" : "Маркирана снимка {title}",
    "{title}'s face" : "Лицето на {title}",
    "Last week" : "Миналата седмица",
    "{startDate} to {endDate}" : "{startDate} до {endDate}",
    "Details" : "Подробности",
    "Remove {collaboratorLabel} from the collaborators list" : "Премахване на {collaboratorLabel} от списъка със сътрудници",
    "Back to {folder}" : "Назад към {folder}",
    "Share this folder" : "Споделяне на тази папка",
    "Loading folders …" : "Зареждане на папките …",
    "Add" : "Добавяне"
},
"nplurals=2; plural=(n != 1);");
